==> nextcloud-16.0.5.tgz: nextcloud/apps/accessibility/l10n/id.js <==
OC.L10N.register(
    "accessibility",
    {
    "Dark theme" : "Tema gelap",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Tema gelap dapat membuat mata anda tidak cepat lelah dengan mengurangi  tingkat kecerahan dan banyaknya cahaya. Fitur ini masih dalam tahap pengembangan, tolong laporkan masalah yang anda temui.",
    "Dyslexia font" : "Font disleksia",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic adalah typeface/font gratis yang didesain untuk mengurangi kesalahan membaca oleh penderita disleksia",
    "Accessibility" : "aksesbilitas",
    "Accessibility options for nextcloud" : "Opsi aksesibilitas untuk nextcloud",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "Menyediakan beberapa opsi aksesibilitas untuk memudahkan Anda menggunakan Nextcloud",
    "Web Content Accessibility Guidelines" : "Pedoman Aksesibilitas Konten Web",
    "our issue tracker" : "pelacak masalah kami",
    "our design team" : "Tim desain kami",
    "Enable" : "aktifkan",
    "High contrast theme" : "Tema kontras tinggi",
    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Tema kontras tinggi untuk memudahkan navigasi Anda. Kualitas visual akan berkurang tetapi kejelasan akan meningkat.",
    "Dark theme (beta)" : "Tema gelap (beta)",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia. The typeface was created by Abelardo Gonzalez, who released it through an open-source license." : "OpenDyslexic adalah jenis huruf / font gratis yang dirancang untuk mengurangi beberapa kesalahan pembacaan umum yang disebabkan oleh disleksia. Jenis huruf ini dibuat oleh Abelardo Gonzalez, yang merilisnya melalui lisensi open-source.",
    "Provides multiple accessibilities options to ease your use of nextcloud" : "72/5000\n \n \n \nMenyediakan beberapa opsi aksesibilitas untuk memudahkan Anda menggunakan nextcloud",
    "Themes" : "Tema",
    "Fonts" : "Huruf",
    "enabled" : "diaktifkan"
},
"nplurals=1; plural=0;");

==> nextcloud-18.0.4.tgz: nextcloud/apps/accessibility/l10n/id.js <==
OC.L10N.register(
    "accessibility",
    {
    "Dark theme" : "Tema gelap",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Tema gelap dapat membuat mata anda tidak cepat lelah dengan mengurangi  tingkat kecerahan dan banyaknya cahaya. Fitur ini masih dalam tahap pengembangan, tolong laporkan masalah yang anda temui.",
    "High contrast mode" : "Mode kontras tinggi",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Mode kontras tinggi untuk memudahkan navigasi Anda. Kualitas visual akan berkurang tetapi kejelasan akan meningkat.",
    "Dyslexia font" : "Font disleksia",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic adalah typeface/font gratis yang didesain untuk mengurangi kesalahan membaca oleh penderita disleksia",
    "Accessibility" : "aksesbilitas",
    "Accessibility options for nextcloud" : "Opsi aksesibilitas untuk nextcloud",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "Menyediakan beberapa opsi aksesibilitas untuk memudahkan Anda menggunakan Nextcloud",
    "High contrast theme" : "Tema kontras tinggi",
    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Tema kontras tinggi untuk memudahkan navigasi Anda. Kualitas visual akan berkurang tetapi kejelasan akan meningkat.",
    "Dark theme (beta)" : "Tema gelap (beta)",
    "Web Content Accessibility Guidelines" : "Pedoman Aksesibilitas Konten Web",
    "our issue tracker" : "pelacak masalah kami",
    "our design team" : "Tim desain kami",
    "Enable" : "aktifkan"
},
"nplurals=1; plural=0;");
